# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' @useDynLib matiming
NULL

#' Computes the mean excess return
#'
#' This function computes the mean excess return. Excess return is the return in excess of the risk-free rate of return
#'
#' @param x the vector of excess returns
#' @return the mean excess return (a scalar)
#' @usage Excret(x)
#' @family performance measures
#' @export
Excret <- function(x) {
    .Call('_matiming_Excret', PACKAGE = 'matiming', x)
}

#' Computes the Sharpe ratio
#'
#' This function computes the Sharpe ratio
#'
#' @param x the vector of excess returns
#' @return the Sharpe ratio (a scalar)
#' @usage Sharpe(x)
#' @family performance measures
#' @references
#' Sharpe, W.F. (1994). The Sharpe Ratio. Journal of Portfolio Management, 21 (1), 49-58.
#' @export
Sharpe <- function(x) {
    .Call('_matiming_Sharpe', PACKAGE = 'matiming', x)
}

#' Computes the Sortino ratio
#'
#' This function computes the Sortino ratio
#'
#' @param x the vector of excess returns
#' @return the Sortino ratio (a scalar)
#' @usage Sortino(x)
#' @family performance measures
#' @references
#' Sortino, F.A. and Price, L.N. (1994). Performance measurement in a downside risk framework. Journal of Investing, 3 (3), 59-64.
#' @export
Sortino <- function(x) {
    .Call('_matiming_Sortino', PACKAGE = 'matiming', x)
}

#' Computes the Simple Moving Average (SMA)
#'
#' This function computes the SMA of prices
#'
#' @param price the vector of prices
#' @param n the length of the averaging window (a scalar)
#' @return the SMA of prices (a vector)
#' @usage SMA(price, n)
#' @family moving average functions
#' @export
SMA <- function(price, n) {
    .Call('_matiming_SMA', PACKAGE = 'matiming', price, n)
}

#' Computes the Linear Moving Average (LMA)
#'
#' This function computes the LMA of prices
#'
#' @param price the vector of prices
#' @param n the length of the averaging window (a scalar)
#' @return the LMA of prices (a vector)
#' @usage LMA(price, n)
#' @family moving average functions
#' @export
LMA <- function(price, n) {
    .Call('_matiming_LMA', PACKAGE = 'matiming', price, n)
}

#' Computes the Exponential Moving Average (EMA)
#'
#' This function computes the infinite EMA of prices
#'
#' @param price the vector of prices
#' @param n the length of the averaging window (a scalar.
#' @note By definition, \eqn{n} is the length of the averaging window in SMA that has the same average lag time as EMA
#' @return the EMA of prices (a vector)
#' @usage EMA(price, n)
#' @family moving average functions
#' @export
EMA <- function(price, n) {
    .Call('_matiming_EMA', PACKAGE = 'matiming', price, n)
}

mae_signal <- function(price, lower, upper) {
    .Call('_matiming_mae_signal', PACKAGE = 'matiming', price, lower, upper)
}

MOM <- function(price, n) {
    .Call('_matiming_MOM', PACKAGE = 'matiming', price, n)
}

sim_strategy <- function(totret, rfret, buy_signal, tc, shorts, start) {
    .Call('_matiming_sim_strategy', PACKAGE = 'matiming', totret, rfret, buy_signal, tc, shorts, start)
}

stat_bootstrap <- function(x, bLen) {
    .Call('_matiming_stat_bootstrap', PACKAGE = 'matiming', x, bLen)
}

block_bootstrap <- function(x, bLen) {
    .Call('_matiming_block_bootstrap', PACKAGE = 'matiming', x, bLen)
}

simple_bootstrap <- function(x) {
    .Call('_matiming_simple_bootstrap', PACKAGE = 'matiming', x)
}

