% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmatiming.r
\name{outperformance.test}
\alias{outperformance.test}
\title{Tests whether the moving average strategy outperforms its passive counterpart}
\usage{
outperformance.test(results, digits=3, to.annual=sqrt(12),
                           type=c("ordinary", "block","stationary"),
                           bLen=5, R=1000, automatic=FALSE)
}
\arguments{
\item{results}{the results returned by function \code{\link{forward.test}} or \code{\link{back.test}}}

\item{digits}{defines the number of digits after the decimal delimiter to use in reporting
the performance of the moving average and buy-and-hold strategies}

\item{to.annual}{a coefficient used to annualize the performance measure. For example, when
the performance is measured using either \code{\link{Sharpe}} or \code{\link{Sortino}},
use \code{sqrt(252)} and \code{sqrt(12)} when the returns are at the daily and monthly frequency respectively.
If the performance is measred by \code{\link{Excret}}, use \code{12}}

\item{type}{determines the type of the bootstrap method. The default type is "ordinary" (the method of Efron, 1979).
The two other types are "block" (the method of Kunsch, 1989) and "stationary" (the method of Politis and Romano, 1994)}

\item{bLen}{a scalar that specifies the block length in the block-bootstrap method}

\item{R}{a scalar that specifies the number of bootstrap replicates}

\item{automatic}{a logical variable that specifies whether to compute the optimal block length
for the block-bootstrap and stationary bootstrap}
}
\value{
The p-value of the outperformance test.
}
\description{
This function tests whether the moving average strategy outperforms its passive counterpart. All tests are based on using a bootstrap method.
}
\note{
If \code{results} are produced by \code{\link{back.test}}, then this function
 tests whether the best strategy in the back test outperforms the buy-and-hold strategy. Note that in this case the p-value is not ajdusted for the data-mining bias.
 Otherwise, if \code{results} are produced by \code{\link{forward.test}}, then this function
 tests whether the out-of-sample strategy outperforms the buy-and-hold strategy.

 Regardless of the performance measure used (denoted by \eqn{PM}),
 this function performs the tests of the following null hypothesis: \eqn{H_0: PM_{MA}\leq PM_{BH}},
 where \eqn{PM_{MA}} is the performance of the moving average strategy and
 \eqn{PM_{BH}} is the performance of the buy-and-hold strategy. In words, the null hypothesis
 is that the performance of the moving average strategy is not better than the performance
 of the buy-and-hold strategy.

 All tests are based on non-parametric bootstrap methods. The three bootstrap methods that are implemented are: (1) the ordinary
 bootstrap method of Efron (1979), (2) the block-bootstrap method of Kunsch (1989), and (3) the stationary block-bootstrap
 method of Politis and Romano (1994). In a block-bootstrap method one needs to either specify manually the block length or
 to allow the function to automatically determine the optimal block length. The optimal
 block length is computed using the method described in Patton, Politis and White (2009). To determine
 the optimal block length, function \code{b.star} from package \code{np} is used (Hayfield and Racine (2008)).
}
\examples{
# Suppose that "results" are the results of simulations of different trading strategies
\dontrun{
start.date <- as.Date("1930-01-01", format="\%Y-\%m-\%d")
end.is.date <- as.Date("1939-12-31", format="\%Y-\%m-\%d")
end.oos.date <- as.Date("2015-12-31", format="\%Y-\%m-\%d")
refit.every <- 5
include.bh <- TRUE
res <- forward.test(results, start.date=start.date, end.is.date=end.is.date,
    end.oos.date=end.oos.date, refit.every=refit.every, include.bh=include.bh, FUN=Sortino)
outperformance.test(res, type="stationary", automatic=TRUE)
}
}
\references{
Efron, B., Bootstrap Methods: Another Look at the Jackknife. Annals of Statistics, 1979, 7, 1-26.

Kunsch, H.R., The Jacknife and the Bootstrap for General Stationary Observations. Annals of Statistics, 1989, 17, 1217-1241.

Politis, D. and Romano, J., The Stationary Bootstrap. Journal of the American Statistical Association, 1994, 89, 1303-1313.

Politis, D.N. and H. White (2004), Automatic block-length selection for the dependent bootstrap, Econometric Reviews 23 (1), 53-70.

Patton, A. and D.N. Politis and H. White (2009), CORRECTION TO: Automatic block-length selection for the dependent bootstrap by D. Politis and H. White, Econometric Reviews 28 (4), 372-375.

Hayfield, T. and J. Racine (2008). Nonparametric Econometrics: The np Package. Journal of Statistical Software, 27 (5).
}
\seealso{
Other strategy testing functions: 
\code{\link{back.test}()},
\code{\link{forward.test}()}
}
\concept{strategy testing functions}
