% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmatiming.r
\name{sim.mac.strategy}
\alias{sim.mac.strategy}
\title{Simulates the returns to the Moving Average Crossover (MAC) strategy}
\usage{
sim.mac.strategy(totret, rfret, dates, capret=NULL, tc=0, shorts = FALSE,
                        fast=50, slow=200, FUN=SMA)
}
\arguments{
\item{totret}{the vector of total returns}

\item{rfret}{the vector of risk-free returns}

\item{dates}{the vector of dates}

\item{capret}{the vector of capital gain returns}

\item{tc}{the amount of one-way transaction costs (a scalar)}

\item{shorts}{a logical value indicating the type of the strategy when a Sell signal is generated.
If \code{shorts=FALSE}, money is just invested in cash; otherwise, the asset is sold short}

\item{fast}{a vector or a scalar that determines the size of the shorter averaging window}

\item{slow}{a vector or a scalar that determines the size of the longer averaging window}

\item{FUN}{a function that determines the type of a moving average}
}
\value{
An object to be used by other functions. This object contains the returns to
the simulated strategies and the description of each strategy (the type of a moving average,
the sizes of the shorter and the longer windows)
}
\description{
This function simulates the returns to the MAC strategy
}
\note{
The function \code{FUN} is either \code{\link{SMA}}, \code{\link{LMA}}, \code{\link{EMA}},
\code{\link{DMA}}, \code{\link{HMA}} or \code{\link{ZMA}}. The trading signal is computed using the vector of capital gain returns \code{capret}. If \code{capret=NULL},
then the trading signal is computed using the vector of total returns \code{totret}.
If one of the arguments \code{fast} or \code{slow} is a vector, then the function simulates a number
of trading strategies for all combinations of \code{fast} and \code{slow} such that \code{fast} \eqn{<} \code{slow}
}
\examples{
\dontrun{
data <- djia.monthly # use the monthly data for DJIA index
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]
tc <- 0.0025 # this defines 0.25\% one-way transaction costs
fast <- 1:8  # define the sizes of the fast (shorter) averaging window
slow <- 2:15 # define the sizes of the slow (longer) averaging window
shorts <- FALSE
results <- sim.mac.strategy(totret=totret, rfret=rfret, dates=dates,
                            capret=capret, tc=tc, shorts=shorts, fast=fast, slow=slow, FUN=EMA)
}
}
\seealso{
Other strategy simulation functions: 
\code{\link{sim.cdir.strategy}()},
\code{\link{sim.macd.strategy}()},
\code{\link{sim.mae.strategy}()},
\code{\link{sim.mom.strategy}()}
}
\concept{strategy simulation functions}
