% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmatiming.r
\name{sim.macd.strategy}
\alias{sim.macd.strategy}
\title{Simulates the returns to the Moving Average Convergence Divergence (MACD) strategy}
\usage{
sim.macd.strategy(totret, rfret, dates, capret=NULL, tc=0, shorts = FALSE,
                         fast=12, slow=26, final=9, FUN=EMA)
}
\arguments{
\item{totret}{the vector of total returns}

\item{rfret}{the vector of risk-free returns}

\item{dates}{the vector of dates}

\item{capret}{the vector of capital gain returns}

\item{tc}{the amount of one-way transaction costs (a scalar)}

\item{shorts}{a logical value indicating the type of the strategy when a Sell signal is generated.
If \code{shorts=FALSE}, money is just invested in cash; otherwise, the asset is sold short}

\item{fast}{a vector or a scalar that determines the size of the shorter averaging window}

\item{slow}{a vector or a scalar that determines the size of the longer averaging window}

\item{final}{a vector or a scalar that determines the size of the window for final smoothing}

\item{FUN}{a function that determines the type of a moving average}
}
\value{
An object to be used by other functions. This object contains the returns to
the simulated strategies and the description of each strategy (the type of a moving average,
the sizes of the shorter and the longer windows, the size of the window for final smoothing)
}
\description{
This function simulates the returns to the MACD strategy
}
\note{
The function \code{FUN} is either \code{\link{SMA}}, \code{\link{LMA}}, \code{\link{EMA}},
\code{\link{DMA}}, \code{\link{HMA}} or \code{\link{ZMA}}. The trading signal is computed using the vector of capital gain returns \code{capret}. If \code{capret=NULL},
then the trading signal is computed using the vector of total returns \code{totret}.
If one of the arguments \code{fast}, \code{slow} or \code{final} is a vector, then the function simulates a number
of trading strategies for all combinations of \code{fast}, \code{slow} and \code{final}
 such that \code{fast} \eqn{<} \code{slow} and \code{final} \eqn{>1}.
}
\examples{
\dontrun{
data <- djia.daily # use the daily data for DJIA index
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]
tc <- 0.0025 # this defines 0.25\% one-way transaction costs
fast <- 1:15 # define the sizes of the fast (shorter) averaging window
slow <- 2:45 # define the sizes of the slow (longer) averaging window
final <- 2:20 # defines the sizes of the window for final smoothing
shorts <- FALSE
results <- sim.macd.strategy(totret=totret, rfret=rfret, dates=dates,
 capret=capret, tc=tc, shorts=shorts, fast=fast, slow=slow,
 final=final, FUN=EMA)
}
}
\seealso{
Other strategy simulation functions: 
\code{\link{sim.cdir.strategy}()},
\code{\link{sim.mac.strategy}()},
\code{\link{sim.mae.strategy}()},
\code{\link{sim.mom.strategy}()}
}
\concept{strategy simulation functions}
