% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmatiming.r
\name{sim.mae.strategy}
\alias{sim.mae.strategy}
\title{Simulates the returns to the Moving Average Envelope (MAE) strategy}
\usage{
sim.mae.strategy(totret, rfret, dates, capret=NULL, tc=0, shorts = FALSE,
                        winsize=200, percentage=1, FUN=SMA)
}
\arguments{
\item{totret}{the vector of total returns}

\item{rfret}{the vector of risk-free returns}

\item{dates}{the vector of dates}

\item{capret}{the vector of capital gain returns}

\item{tc}{the amount of one-way transaction costs (a scalar)}

\item{shorts}{a logical value indicating the type of the strategy when a Sell signal is generated.
If \code{shorts=FALSE}, money is just invested in cash; otherwise, the asset is sold short}

\item{winsize}{a vector or a scalar that determines the size of the averaging window}

\item{percentage}{a vector or a scalar that determines the envelope percentage}

\item{FUN}{a function that determines the type of a moving average}
}
\value{
An object to be used by other functions. This object contains the returns to
the simulated strategies and the description of each strategy (the type of a moving average,
the sizes of the averaging windows, and the envelope percentages)
}
\description{
This function simulates the returns to the MAE strategy
}
\note{
The function \code{FUN} is either \code{\link{SMA}}, \code{\link{LMA}}, \code{\link{EMA}},
\code{\link{DMA}}, \code{\link{HMA}} or \code{\link{ZMA}}. The trading signal is computed using the vector of capital gain returns \code{capret}. If \code{capret=NULL},
then the trading signal is computed using the vector of total returns \code{totret}.
}
\examples{
\dontrun{
data <- djia.monthly # use the monthly data for DJIA index
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]
tc <- 0.0025 # this defines 0.25\% one-way transaction costs
winsize <- 2:20
percentage <- 0:10
shorts <- FALSE
results <- sim.mae.strategy(totret=totret, rfret=rfret, dates=dates,
                            capret=capret, tc=tc, winsize=winsize,
                            percentage=percentage, slow=slow, FUN=EMA)
}
}
\seealso{
Other strategy simulation functions: 
\code{\link{sim.cdir.strategy}()},
\code{\link{sim.mac.strategy}()},
\code{\link{sim.macd.strategy}()},
\code{\link{sim.mom.strategy}()}
}
\concept{strategy simulation functions}
