% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rmatiming.r
\name{sim.mom.strategy}
\alias{sim.mom.strategy}
\title{Simulates the returns to the Momentum (MOM) strategy}
\usage{
sim.mom.strategy(totret, rfret, dates, capret=NULL, tc=0,
                        shorts = FALSE, winsize=200)
}
\arguments{
\item{totret}{the vector of total returns}

\item{rfret}{the vector of risk-free returns}

\item{dates}{the vector of dates}

\item{capret}{the vector of capital gain returns}

\item{tc}{the amount of one-way transaction costs (a scalar)}

\item{shorts}{a logical value indicating the type of the strategy when a Sell signal is generated.
If \code{shorts=FALSE}, money is just invested in cash; otherwise, the asset is sold short}

\item{winsize}{a vector or a scalar that determines the size of the window used to compute the MOM}
}
\value{
An object to be used by other functions. This object contains the returns to
the simulated strategies and the description of each strategy
}
\description{
This function simulates the returns to the MOM strategy
}
\note{
The trading signal is computed using the vector of capital gain returns \code{capret}. If \code{capret=NULL},
then the trading signal is computed using the vector of total returns \code{totret}.
If \code{winsize} is a vector, then the function simulates a number
of trading strategies for all window sizes such that \code{winsize} \eqn{>1}
}
\examples{
\dontrun{
data <- djia.monthly # use the monthly data for DJIA index
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]
tc <- 0.0025 # this defines 0.25\% one-way transaction costs
winsize <- 2:15
shorts <- FALSE
results <- sim.mom.strategy(totret=totret, rfret=rfret, dates=dates,
                            capret=capret, tc=tc, shorts=shorts, winsize=winsize)
}
}
\seealso{
Other strategy simulation functions: 
\code{\link{sim.cdir.strategy}()},
\code{\link{sim.mac.strategy}()},
\code{\link{sim.macd.strategy}()},
\code{\link{sim.mae.strategy}()}
}
\concept{strategy simulation functions}
